@@ -20,8 +20,9 @@
 
 
 from timeside.core import Processor, implements, interfacedoc
+from timeside.encoder.core import GstEncoder
 from timeside.api import IEncoder
-from timeside.encoder.gstutils import *
+from timeside.tools import *
 
 class VorbisEncoder(GstEncoder):
     """ gstreamer-based vorbis encoder """
@@ -33,36 +34,36 @@ class VorbisEncoder(GstEncoder):
         else:
             self.filename = None
         self.streaming = streaming
-        
+
         if not self.filename and not self.streaming:
             raise Exception('Must give an output')
-        
+
         self.eod = False
 
     @interfacedoc
-    def setup(self, channels=None, samplerate=None, nframes=None):
-        super(VorbisEncoder, self).setup(channels, samplerate, nframes)
-        # TODO open file for writing
-        # the output data format we want        
+    def setup(self, channels=None, samplerate=None, blocksize=None, totalframes=None):
+        super(VorbisEncoder, self).setup(channels, samplerate, blocksize, totalframes)
+
         self.pipe = ''' appsrc name=src
-                  ! audioconvert 
+                  ! audioconvert
                   ! vorbisenc
                   ! oggmux
                   '''
+
         if self.filename and self.streaming:
             self.pipe += ''' ! tee name=t
             ! queue ! filesink location=%s
             t. ! queue ! appsink name=app sync=False
             ''' % self.filename
-            
+
         elif self.filename :
-            self.pipe += '! filesink async=True location=%s ' % self.filename
+            self.pipe += '! filesink location=%s async=False sync=False ' % self.filename
         else:
-            self.pipe += '! appsink name=app sync=False '
-            
-        # start pipeline
+            self.pipe += '! queue ! appsink name=app sync=False '
+
         self.start_pipeline(channels, samplerate)
 
+
     @staticmethod
     @interfacedoc
     def id():
@@ -90,5 +91,5 @@ class VorbisEncoder(GstEncoder):
 
     @interfacedoc
     def set_metadata(self, metadata):
-        #TODO:
-        pass
+        self.metadata = metadata
+
